pub struct LocalDissentRecordV1 {
pub schema_version: String,
pub local_dissent_id: LocalDissentId,
pub runtime_name: String,
pub reason: String,
pub blocks_shared_settlement: bool,
}Fields
schema_version: Stringlocal_dissent_id: LocalDissentIdruntime_name: Stringreason: StringTrait Implementations
Sourceimpl Clone for LocalDissentRecordV1
impl Clone for LocalDissentRecordV1
Sourcefn clone(&self) -> LocalDissentRecordV1
fn clone(&self) -> LocalDissentRecordV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LocalDissentRecordV1
impl Debug for LocalDissentRecordV1
Sourceimpl<'de> Deserialize<'de> for LocalDissentRecordV1
impl<'de> Deserialize<'de> for LocalDissentRecordV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LocalDissentRecordV1
Sourceimpl JsonSchema for LocalDissentRecordV1
impl JsonSchema for LocalDissentRecordV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LocalDissentRecordV1
impl PartialEq for LocalDissentRecordV1
Sourcefn eq(&self, other: &LocalDissentRecordV1) -> bool
fn eq(&self, other: &LocalDissentRecordV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LocalDissentRecordV1
impl Serialize for LocalDissentRecordV1
impl StructuralPartialEq for LocalDissentRecordV1