pub struct RuntimeIdentitySetV1 {
pub schema_version: String,
pub runtime_identity_set_id: RuntimeIdentitySetId,
pub treaty_bundle_id: TreatyBundleId,
pub identities: Vec<RuntimeIdentityRecordV1>,
pub canonical_owner: String,
pub publication_status: SurfaceStatus,
}Fields
schema_version: Stringruntime_identity_set_id: RuntimeIdentitySetIdtreaty_bundle_id: TreatyBundleIdidentities: Vec<RuntimeIdentityRecordV1>canonical_owner: Stringpublication_status: SurfaceStatusTrait Implementations
Sourceimpl Clone for RuntimeIdentitySetV1
impl Clone for RuntimeIdentitySetV1
Sourcefn clone(&self) -> RuntimeIdentitySetV1
fn clone(&self) -> RuntimeIdentitySetV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeIdentitySetV1
impl Debug for RuntimeIdentitySetV1
Sourceimpl<'de> Deserialize<'de> for RuntimeIdentitySetV1
impl<'de> Deserialize<'de> for RuntimeIdentitySetV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeIdentitySetV1
Sourceimpl JsonSchema for RuntimeIdentitySetV1
impl JsonSchema for RuntimeIdentitySetV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RuntimeIdentitySetV1
impl PartialEq for RuntimeIdentitySetV1
Sourcefn eq(&self, other: &RuntimeIdentitySetV1) -> bool
fn eq(&self, other: &RuntimeIdentitySetV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RuntimeIdentitySetV1
impl Serialize for RuntimeIdentitySetV1
impl StructuralPartialEq for RuntimeIdentitySetV1