pub struct SharedDivergenceReportV1 {
pub schema_version: String,
pub shared_divergence_report_id: SharedDivergenceReportId,
pub settlement_case_id: SettlementCaseId,
pub treaty_bundle_id: TreatyBundleId,
pub shared_replay_slice_id: SharedReplaySliceId,
pub citation: V25ConstitutionCitation,
pub blocking_runtime_names: Vec<String>,
pub divergence_summary: String,
pub requires_local_dissent_preservation: bool,
pub recommends_suspension: bool,
pub advisory_only: bool,
}Fields
schema_version: Stringsettlement_case_id: SettlementCaseIdtreaty_bundle_id: TreatyBundleIdcitation: V25ConstitutionCitationblocking_runtime_names: Vec<String>divergence_summary: Stringrequires_local_dissent_preservation: boolrecommends_suspension: booladvisory_only: boolTrait Implementations
Sourcefn clone(&self) -> SharedDivergenceReportV1
fn clone(&self) -> SharedDivergenceReportV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourcefn eq(&self, other: &SharedDivergenceReportV1) -> bool
fn eq(&self, other: &SharedDivergenceReportV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Auto Trait Implementations